/*
 * Copyright (c) 2004 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.tranql.connector.postgresql;

import org.postgresql.ds.PGSimpleDataSource;
import org.tranql.connector.NoExceptionsAreFatalSorter;
import org.tranql.connector.jdbc.AbstractLocalDataSourceMCF;

/**
 * ManagedConnectionFactory that wraps a PGSimpleDataSource.
 *
 * @version $Revision: 518 $ $Date: 2007-09-27 13:21:15 -0700 (Thu, 27 Sep 2007) $
 */
public class PGSimpleLocalMCF extends AbstractLocalDataSourceMCF {
    private final PGSimpleDataSource ds;

    /**
     * Default constructor for a PostgreSQL Local DataSource.
     */
    public PGSimpleLocalMCF() {
        super(new PGSimpleDataSource(), new NoExceptionsAreFatalSorter(), false);
        ds = (PGSimpleDataSource) super.dataSource;
    }

    /**
     * Return the user name used to establish the connection.
     *
     * @return the user name used to establish the connection
     */
    public String getUserName() {
        return ds.getUser();
    }

    /**
     * Set the user name used establish the connection. This value is used if no
     * connection information is supplied by the application when attempting to
     * create a connection.
     *
     * @param userName the user name used to establish the connection; may be null
     */
    public void setUserName(String userName) {
        ds.setUser(userName);
    }

    /**
     * Return the password credential used to establish the connection.
     *
     * @return the password credential used to establish the connection
     */
    public String getPassword() {
        return ds.getPassword();
    }

    /**
     * Set the user password credential establish the connection. This value is
     * used if no connection information is supplied by the application when
     * attempting to create a connection.
     *
     * @param password the password credential used to establish the connection; may
     *                 be null
     */
    public void setPassword(String password) {
        ds.setPassword(password);
    }

    /**
     * Return the database name.
     *
     * @return the database name
     */
    public String getDatabaseName() {
        return ds.getDatabaseName();
    }

    /**
     * Set the database name.
     *
     * @param databaseName the database name
     */
    public void setDatabaseName(String databaseName) {
        ds.setDatabaseName(databaseName);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getPortNumber()
     */
    public Integer getPortNumber() {
        return new Integer(ds.getPortNumber());
    }

    /**
     * @param portNumber
     * @see org.postgresql.ds.common.BaseDataSource#setPortNumber(int)
     */
    public void setPortNumber(Integer portNumber) {
        ds.setPortNumber(portNumber.intValue());
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getPrepareThreshold()
     */
    public Integer getPrepareThreshold() {
        return new Integer(ds.getPrepareThreshold());
    }

    /**
     * @param threshold
     * @see org.postgresql.ds.common.BaseDataSource#setPrepareThreshold(int)
     */
    public void setPrepareThreshold(Integer threshold) {
        ds.setPrepareThreshold(threshold.intValue());
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getServerName()
     */
    public String getServerName() {
        return ds.getServerName();
    }

    /**
     * @param serverName
     * @see org.postgresql.ds.common.BaseDataSource#setServerName(java.lang.String)
     */
    public void setServerName(String serverName) {
        ds.setServerName(serverName);
    }

}
